# 2D Statistics Plot

Plot two statistics on a scatter plot. A point (X,Y) is drawn for every pair of elements with the same value of Variable; the X value is from ** X statistic** and the Y value is from Y statistic.

X Statistic

  Which statistic to plot on the X axis.

Y Statistic

  Which statistic to plot on the Y axis. Must have the same indices as X Statistic.

X Scale, Y Scale

  How to scale the X and Y axes.

Variable

  The statistic variable to put on the plot.

Horizontal Facet

  Make muliple plots, with each column representing a subset of the statistic with a different value for this variable.

Vertical Facet

  Make multiple plots, with each row representing a subset of the statistic with a different value for this variable.

Color Facet

  Make lines on the plot with different colors; each color represents a subset of the statistic with a different value for this variable.

Color Scale

  If Color Facet is a numeric variable, use this scale for the color bar.

X Error Statistic

  A statistic to use to make error bars in the X direction. Must have the same indices as the statistic in X Statistic.

Y Error Statistic

  A statistic to use to make error bars in the Y direction. Must have the same indices as the statistic in Y Statistic.

Subset

  Plot only a subset of the statistic.